==> ovirt-engine-sdk-java-4.1.2.tar.gz: ovirt-engine-sdk-java-4.1.2/target/generated-sources/org/ovirt/engine/sdk4/services/OpenstackImageProvidersService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.OpenStackImageProviderBuilder;
import org.ovirt.engine.sdk4.types.OpenStackImageProvider;

public interface OpenstackImageProvidersService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest provider(OpenStackImageProvider provider);
        AddRequest provider(OpenStackImageProviderBuilder provider);
    }
    
    public interface AddResponse extends Response {
        OpenStackImageProvider provider();
    }
    
    AddRequest add();
    
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    public interface ListResponse extends Response {
        List<OpenStackImageProvider> providers();
    }
    
    ListRequest list();
    
    OpenstackImageProviderService providerService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.6.tar.gz: ovirt-engine-sdk-java-4.1.6/target/generated-sources/org/ovirt/engine/sdk4/services/OpenstackImageProvidersService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.OpenStackImageProviderBuilder;
import org.ovirt.engine.sdk4.types.OpenStackImageProvider;

public interface OpenstackImageProvidersService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest provider(OpenStackImageProvider provider);
        AddRequest provider(OpenStackImageProviderBuilder provider);
    }
    
    public interface AddResponse extends Response {
        OpenStackImageProvider provider();
    }
    
    AddRequest add();
    
    /**
     * Returns the list of providers.
     * 
     * The order of the returned list of providers isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of providers to return. If not specified all the providers are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of providers.
     * 
     * The order of the returned list of providers isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<OpenStackImageProvider> providers();
    }
    
    /**
     * Returns the list of providers.
     * 
     * The order of the returned list of providers isn't guaranteed.
     */
    ListRequest list();
    
    OpenstackImageProviderService providerService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
